Hex

Struct Hex 

pub struct Hex(pub bool);
A repr for formatting data in hexadecimal. Implemented for all integers.

The inner bool specifies whether or not output should be uppercase.

Unlike Debug and Pretty, cannot be derived, since most types cannot be intuitively formatted in hex.

Equivalent of core::fmt::LowerHex and core::fmt::UpperHex.

Tuple Fields

0: bool

Implementations

Source

impl Hex

pub fn prefix(uppercase: bool) -> Prefix<&'static str, Self>

Create a new Hex, with the prefix 0x automatically applied.