macro_rules! println {
($($t:tt)*) => { ... };
}Expand description
Print formatted data to stdout with a following newline.
See restd::fmt for details on the syntax.
macro_rules! println {
($($t:tt)*) => { ... };
}Print formatted data to stdout with a following newline.
See restd::fmt for details on the syntax.