pub struct Hex(pub bool);Expand description
A repr for formatting data in hexadecimal. Implemented for all integers.
The inner bool specifies whether or not output should be uppercase.
Unlike Debug and Pretty, cannot be
derived, since most types cannot be intuitively formatted in hex.
Equivalent of core::fmt::LowerHex and core::fmt::UpperHex.
Tuple Fields
0: boolImplementations